159,008 Commits over 4,566 Days - 1.45cph!

15 Minutes Ago
Cleanup
14 Minutes Ago
merge from main
16 Minutes Ago
Skip the gamepad vehicle action set lookup when no Steam Input controller is active
17 Minutes Ago
Only send waterwheel network updates when its actually changed (at low speed) Saves ~76 B per skipped update per nearby player
26 Minutes Ago
Merge from main
30 Minutes Ago
Clear potential stale gamepad inventory cursors in edit mode
46 Minutes Ago
Tooltip bind lookup fix
53 Minutes Ago
Added replayInPlace to EffectRecycle, lets us flag effects that can be replayed in place instead of popping and retiring a pooled copy every time Applied to AK first and 3rd person shell eject effects for now, ~0.13ms -> ~0.04ms per shot Also means we'll only have to prewarm a handful of shell particle prefabs for all the guns
57 Minutes Ago
Adding dweller mace viewmodel rig
1 Hour Ago
Merge from main
1 Hour Ago
merge from main
1 Hour Ago
Use Facepunch.Steamworks GetPngAnalogActionGlyph for stick/trigger glyphs, remove the now unnecessary hacky workaround
1 Hour Ago
Merge from main
1 Hour Ago
Fix motion vector pass being culled when ocean is present
1 Hour Ago
Merge from main (actually latest this time)
1 Hour Ago
Updating tattoo rig with updated mesh
1 Hour Ago
Merge from main, and fix MapInterface marker conflict
1 Hour Ago
Merge from render_pipeline_testing
1 Hour Ago
Merge from render_pipeline_testing
1 Hour Ago
Merge from fp_sw_glyph_fixes
1 Hour Ago
Update Facepunch.Steamworks: fix Steam Input glyph origin buffer overflow, add GetPngAnalogActionGlyph, cache action set handles
2 Hours Ago
Forward jump down animations for cow and sheep
2 Hours Ago
Updating flail viewmodel rig
3 Hours Ago
Rebind rendertarget to camera target after rendergraph and move SetupCameraProperties back
Rin
3 Hours Ago
Handmade SMG damage Increased 20 > 21
5 Hours Ago
▄▆▄▆▅█▋▍ ▉▋▆ ▍▉▇▅█▅▊ ▉█▍▄▇ ▆▍ ▉▇ █▆█ ▌▋▇▆▅▇▄▅▄▄ ▋▌▉▉▋ ▍▍ ▊▅▋▌ ▌▍█▆ ▄▍▌ ▇▉▅▇▊▄▌█ ▊▇▅▌▇▍▊█▊▅█▋▉▍▊▊▆▉ ▊▄▌ ▌▍▅▇▅▋▉ ▍█ ▅▉▊▇▆▊█▆▇▌▆█▋▅▉▅▇▇▍█▄▅█▌▉▋▇▄▉▆▆▅▉▆▍▍▄▅▋▄▅ ▍▆▋▋▇▄▋▉▅ ▌▇▉█▇▄▄▌ ▋▉▆█▋▄▊▅▌ ▉▆▊▅▅▊▌▆▅ ▌▊▄▆▊▊█▇ █▌▉ ▄▍▌▌▆█▅▋
6 Hours Ago
Merge from car_spawning_prefill
6 Hours Ago
Round up the amount of filled slots, so a 5 slot engine gets 3 prefilled instead of 2
6 Hours Ago
Manifest update
6 Hours Ago
Merge from main
6 Hours Ago
Merge from prototype_draggable_markers Can now drag map markers on the map screen with MMB
Today
▉▊▄▅▋▌ █▇▆▌▉█▍ ▍▄▉ ▄▄▇▋▆█▄
Today
▉▄▊▊▌▅ ▉▇▍▅ ▄▌▊▍
Today
Merge from terrain_watermap_test
Today
Remove watermap texture2D creation on procedural map, saves ~89.5MB on 4k map
Today
Merge from livestock_digestion_boost
Today
Cleanup
Today
Merge fixes Apply the dung boost the whole time an animal is eating an item from the trough, not just when the item is consumed (caused gaps in boost coverage) Animals eat a booster item from the trough over any other item
Today
Merge from main (sketchy merge, need to revert any behaviour changes)
Today
Fixed EffectParentToWeaponBone 128B alloc per effect spawn
Today
When in first person, don't spawn effects with HideIfOwnerFirstPerson instead of spawning and hiding them right away Also fixed the 128B alloc in HideIfOwnerFirstPerson.OnEnable Saves 0.1ms when firing the AK
Today
Merge from hardcore_changes_nov_26
Today
Reduced the amount of pooled pilot codelock 200 -> 25 Keylock 1 -> 50
Today
Reduced the amount of pooled blowpipe dart projectiles 100 -> 4
Today
Reduced the amount of pooled ballista projectiles 100 -> 3
Today
Modified hardcore upkeep values Brackets are measured by block count, so these values are for upkeep up to 15/50/125/infinite Vanilla: 0.1/0.15/0.2/0.33 Old Hardcore: 0.2/0.3/0.4/0.66 New hardcore: 0.1/0.15/0.25/0.4 New values should increase upkeep for bases with > 65 blocks but still at a lower level compared to old hardcore
Today
merge from main
Today
Merge from main
Today
Reviewed the amount of bullet impacts and decals we prewarm - Rock, gravel, stones, metal ore and tundra impacts were only warmed with 1 copy, now 25 like the others. - Glass impact 25 -> 32, it stays alive for 4s+ - Bullet decals 25 -> 30, forest was set to 1, cactus lowered to 5
Today
Merge from warm_prefabs_measure